"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FloatingWindow = void 0;
const React = require("react");
const react_dom_1 = require("react-dom");
const Rect_1 = require("../Rect");
const Types_1 = require("../Types");
/** @internal */
const FloatingWindow = (props) => {
    const { title, id, url, rect, onCloseWindow, onSetWindow, children } = props;
    const popoutWindow = React.useRef(null);
    const timerId = React.useRef(null);
    const [content, setContent] = React.useState(undefined);
    React.useLayoutEffect(() => {
        if (timerId.current) {
            clearTimeout(timerId.current);
        }
        let isMounted = true;
        const r = rect || new Rect_1.Rect(0, 0, 100, 100);
        // Make a local copy of the styles from the current window which will be passed into
        // the floating window. window.document.styleSheets is mutable and we can't guarantee
        // the styles will exist when 'popoutWindow.load' is called below.
        popoutWindow.current = window.open(url, id, `left=${r.x},top=${r.y},width=${r.width},height=${r.height}`);
        if (popoutWindow.current !== null) {
            onSetWindow(id, popoutWindow.current);
            // listen for parent unloading to remove all popouts
            window.addEventListener("beforeunload", () => {
                if (popoutWindow.current) {
                    popoutWindow.current.close();
                    popoutWindow.current = null;
                }
            });
            popoutWindow.current.addEventListener("load", () => {
                if (isMounted) {
                    const popoutDocument = popoutWindow.current.document;
                    popoutDocument.title = title;
                    const popoutContent = popoutDocument.body;
                    popoutContent.className = Types_1.CLASSES.FLEXLAYOUT__FLOATING_WINDOW_CONTENT;
                    popoutDocument.body.appendChild(popoutContent);
                    setContent(popoutContent);
                    // listen for popout unloading (needs to be after load for safari)
                    popoutWindow.current.addEventListener("beforeunload", () => {
                        onCloseWindow(id);
                    });
                }
            });
        }
        else {
            console.warn(`Unable to open window ${url}`);
            onCloseWindow(id);
        }
        return () => {
            isMounted = false;
            // delay so refresh will close window
            timerId.current = setTimeout(() => {
                if (popoutWindow.current) {
                    popoutWindow.current.close();
                    popoutWindow.current = null;
                }
            }, 0);
        };
    }, []);
    if (content !== undefined) {
        return (0, react_dom_1.createPortal)(children, content);
    }
    else {
        return null;
    }
};
exports.FloatingWindow = FloatingWindow;
//# sourceMappingURL=FloatingWindow.js.map